@@ -1,10 +1,12 @@
+from random import random
+from time import sleep
 
 
-
-class iodummy(object):
+class IODummy(object):
+    '''Simulates the serial port and io board'''
     def __init__(self):
-        self.__gpio_state = {01: 0, 2: 0, 3: 0, 4: 0, 5: 0, 0: 0}
-        self.__relay_state = {1: 0, 2: 0, 3: 0, 0: 0}
+        self.__gpio_state = {0: 0, 1: 0, 2: 0, 3: 0, 4: 0, 5: 0}
+        self.__relay_state = {0: 0, 1: 0, 2: 0, 3: 0}
         self.__buffer = ''
 
     def _get_pin(self, msg):
@@ -14,6 +16,7 @@ class iodummy(object):
     def read(self, size=1):
         buf = self.__buffer
         self.__buffer == ''
+        sleep(round(random(), 2))
         return buf
 
 
@@ -31,10 +34,17 @@ class iodummy(object):
             elif "off" in msg:
                 self.__relay_state[pin] = 0
         elif "gpio" in msg:
-            pass
+            raise NotImplementedError
 
 
 
     def close(self):
         pass
 
+
+
+    def __enter__(self):
+        return self
+
+    def __exit__(self, type, value, traceback):
+        return self
\ No newline at end of file
